4 strengths
-----------
browsing - visual mode
statistics - 8 lines of unicode blocks
reviewing  - very customizable
opening    - last command with different arg; tab completion; BASH ALIASES 

REVIEW (for basic reviewer)

     |  cont  |   no
-----|--------|--------
save |  enter |   
-----|--------|--------
no   |   x    |  q,esc
-----|--------|--------

go back in review
-h,u    no history change, see prev card
go back in preview
-u      delete current card, see prev card
-h      make current card, see prev card

PREVIEW (for viewing cards while in add mode)
- inherits cmds from REVIEW
- disinherits grading cmds
- many commands like for vb start the editor and pass it an argument
- w   create the card and open another (of the same type)
- ent create the card and open another (of the same type)
- q   discard (delete) the card without saving and return to home
- x   create the card and return to home
- H   edit the most recent card (can be repeated to go farther back)
- o   create image occlusion; key-bindings to types should not interfere
